@@ -725,6 +725,9 @@ class cmd_merge_upstream(Command):
         'snapshot', help="Merge a snapshot from the "
         "upstream branch rather than a new upstream release.")
 
+    release_opt = Option(
+        'release', help='Merge a release from the upstream branch.')
+
     force_pristine_tar_opt = Option(
         'force-pristine-tar', help=(
             'Force the use of pristine-tar, even if no '
@@ -745,7 +748,7 @@ class cmd_merge_upstream(Command):
         distribution_opt, directory_opt, last_version_opt,
         force_opt, 'revision', 'merge-type',
         snapshot_opt, force_pristine_tar_opt,
-        dist_command_opt, guess_upstream_branch_url_opt]
+        dist_command_opt, guess_upstream_branch_url_opt, release_opt]
 
     def run(self, location: Optional[str] = None,
             upstream_branch: Optional[str] = None,
@@ -754,6 +757,7 @@ class cmd_merge_upstream(Command):
             directory: str = ".", revision=None, merge_type=None,
             last_version: Optional[str] = None,
             force: Optional[bool] = None, snapshot: Optional[bool] = None,
+            release: Optional[bool] = None,
             force_pristine_tar: bool = False,
             dist_command: Optional[str] = None,
             guess_upstream_branch_url: bool = False):
@@ -799,14 +803,17 @@ class cmd_merge_upstream(Command):
                     "package name, which is needed to know the name to "
                     "give the .orig.tar.gz. Please specify --package.")
 
-            if snapshot is None:
+            if snapshot is None and release is None:
                 if current_version is not None:
                     version_kind = detect_version_kind(current_version)
                 else:
                     version_kind = None
-            elif snapshot is True:
+            elif snapshot is not None and release is not None:
+                raise BzrCommandError(
+                    '--release and --snapshot are incompatible')
+            elif snapshot:
                 version_kind = "snapshot"
-            elif snapshot is False:
+            elif release:
                 version_kind = "release"
 
             if version_kind is None:
@@ -1399,53 +1406,6 @@ class cmd_builddeb_do(Command):
                      '"bzr add" or "bzr rm" as appropriate.'))
 
 
-class cmd_mark_uploaded(Command):
-    """Mark that this branch has been uploaded, prior to pushing it.
-
-    When a package has been uploaded we want to mark the revision
-    that it was uploaded in. This command automates doing that
-    by marking the current tip revision with the version indicated
-    in debian/changelog.
-    """
-    force = Option(
-        'force', help="Mark the upload even if it is already marked.")
-
-    takes_options = [merge_opt, force]
-    hidden = True
-
-    def run(self, merge=None, force=None):
-        from .import_dsc import (
-            DistributionBranch,
-            DistributionBranchSet,
-            )
-        from .util import (
-            find_changelog,
-            )
-        t, subpath = WorkingTree.open_containing('.')
-        with t.lock_write():
-            _check_uncommitted(t, subpath)
-            config = debuild_config(t, subpath)
-            if merge is None:
-                merge = (config.build_type == BUILD_TYPE_MERGE)
-            (changelog, top_level) = find_changelog(t, subpath, merge=merge)
-            if changelog.distributions == 'UNRELEASED':
-                if not force:
-                    raise BzrCommandError(gettext(
-                        "The changelog still targets "
-                        "'UNRELEASED', so apparently hasn't been uploaded."))
-            db = DistributionBranch(t.branch, None)
-            dbs = DistributionBranchSet()
-            dbs.add_branch(db)
-            if db.has_version(changelog.version):
-                if not force:
-                    raise BzrCommandError(gettext(
-                        "This version has already been "
-                        "marked uploaded. Use --force to force marking "
-                        "this new version."))
-            tag_name = db.tag_version(changelog.version)
-            self.outf.write(gettext("Tag '%s' created.\n") % tag_name)
-
-
 class cmd_dep3_patch(Command):
     """Format the changes in a branch as a DEP-3 patch.
 
@@ -1650,5 +1610,10 @@ class cmd_debrelease(Command):
                         target_dir=(td if not skip_upload else None),
                         builder=builder)
                 if not skip_upload:
-                    dput_changes(changes_files['source'])
+                    try:
+                        source_path = changes_files['source']
+                    except KeyError:
+                        raise BzrCommandError(
+                            'No source package was created by build command')
+                    dput_changes(source_path)
             local_tree.branch.push(branch)
