@@ -30,6 +30,7 @@ from contextlib import contextmanager, ExitStack
 import os
 import stat
 import tempfile
+from typing import Optional
 
 from debian import deb822
 from debian.changelog import Version, Changelog, VersionError
@@ -39,9 +40,6 @@ from ... import (
     controldir,
     osutils,
     )
-from ...export import (
-    export,
-    )
 from ...config import ConfigObj
 from ...errors import (
     BzrError,
@@ -63,6 +61,7 @@ from .errors import (
     )
 from .extract import extract
 from .util import (
+    export_with_nested,
     extract_orig_tarballs,
     get_commit_info_from_changelog,
     md5sum_filename,
@@ -214,8 +213,9 @@ def checkout_upstream_version(tree, package, version, revisions):
         revid = revisions[component]
         if component is not None:
             component_tree = tree.branch.repository.revision_tree(revid)
-            export(component_tree, os.path.join(tree.basedir, component),
-                   format='dir')
+            export_with_nested(
+               component_tree, os.path.join(tree.basedir, component),
+               format='dir')
         parent_ids.append(revid)
     tree.set_parent_ids(parent_ids)
 
@@ -296,7 +296,7 @@ class DistributionBranch(object):
         """
         return self.get_lesser_branches() + self.get_greater_branches()
 
-    def tag_name(self, version, vendor=None):
+    def tag_name(self, version, vendor: Optional[str]):
         """Gets the name of the tag that is used for the version.
 
         :param version: the Version object that the tag should refer to.
