@@ -166,7 +166,7 @@ class DistributionBranchTests(BuilddebTestCase):
         db = self.db1
         version_no = "0.1-1"
         version = Version(version_no)
-        self.assertEqual(db.tag_name(version), version_no)
+        self.assertEqual(db.tag_name(version, None), version_no)
 
     def test_tag_version(self):
         db = self.db1
@@ -175,7 +175,7 @@ class DistributionBranchTests(BuilddebTestCase):
         revid = tree.commit("one")
         db.tag_version(version)
         self.assertEqual(
-            tree.branch.tags.lookup_tag(db.tag_name(version)), revid)
+            tree.branch.tags.lookup_tag(db.tag_name(version, None)), revid)
 
     def test_tag_upstream_version(self):
         db = self.db1
@@ -1731,7 +1731,7 @@ class DistributionBranchTests(BuilddebTestCase):
         builder.build()
         upstream_tree = self.make_branch_and_tree("upstream")
         self.build_tree(['upstream/a'])
-        upstream_tree.add(['a'], [b'a-id'])
+        upstream_tree.add(['a'], ids=[b'a-id'])
         upstream_tree.commit("one")
         upstream_rev = upstream_tree.branch.last_revision()
         db = DistributionBranch(tree.branch, tree.branch, tree=tree)
@@ -1795,7 +1795,7 @@ class DistributionBranchTests(BuilddebTestCase):
         upstream_tree.lock_write()
         self.addCleanup(upstream_tree.unlock)
         self.build_tree(['upstream/a'])
-        upstream_tree.add(['a'], [b'a-id'])
+        upstream_tree.add(['a'], ids=[b'a-id'])
         upstream_rev1 = upstream_tree.commit("one")
         tree = upstream_tree.controldir.sprout('packaging').open_workingtree()
         db = DistributionBranch(tree.branch, tree.branch, tree=tree)
@@ -1832,7 +1832,7 @@ class DistributionBranchTests(BuilddebTestCase):
         upstream_tree.lock_write()
         self.addCleanup(upstream_tree.unlock)
         self.build_tree(['upstream/a', 'upstream/b'])
-        upstream_tree.add(['a', 'b'], [b'a-id', b'b-id'])
+        upstream_tree.add(['a', 'b'], ids=[b'a-id', b'b-id'])
         upstream_rev1 = upstream_tree.commit("one")
         tree = upstream_tree.controldir.sprout('packaging').open_workingtree()
         db = DistributionBranch(tree.branch, tree.branch, tree=tree)
@@ -1870,7 +1870,7 @@ class DistributionBranchTests(BuilddebTestCase):
         packaging_tree.lock_write()
         self.addCleanup(packaging_tree.unlock)
         self.build_tree(['packaging/a'])
-        packaging_tree.add(['a'], [b'a-id'])
+        packaging_tree.add(['a'], ids=[b'a-id'])
         upstream_rev1 = packaging_tree.commit("one")
         db = DistributionBranch(
             packaging_tree.branch, packaging_tree.branch,
@@ -1879,7 +1879,7 @@ class DistributionBranchTests(BuilddebTestCase):
         dbs.add_branch(db)
         packaging_tree.rename_one('a', 'b')
         self.build_tree(['packaging/a'])
-        packaging_tree.add(['a'], [b'other-a-id'])
+        packaging_tree.add(['a'], ids=[b'other-a-id'])
         packaging_tree.commit("add packaging")
         packaging_tree.branch.tags.set_tag(
             "upstream-%s" % version1.upstream_version, upstream_rev1)
