@@ -19,17 +19,19 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 from contextlib import ExitStack
-from debian.changelog import Version
+from datetime import date
 import os
 import re
 import subprocess
 import tempfile
 from typing import Optional, Tuple, Iterable
 
+from debian.changelog import Version
 from debmutate.versions import (
     git_snapshot_data_from_version,
     get_snapshot_revision as _get_snapshot_revision,
     debianize_upstream_version,
+    upstream_version_add_revision as _upstream_version_add_revision,
     )
 
 from .... import osutils
@@ -60,14 +62,12 @@ from ..errors import (
     MultipleUpstreamTarballsNotSupported,
     )
 from .. import gettext
+from ..util import export_with_nested
 from . import (
     UpstreamSource,
     PackageVersionNotPresent,
     new_tarball_name,
     )
-from ....export import (
-    export,
-    )
 from ....workingtree import (
     WorkingTree,
     )
@@ -223,7 +223,6 @@ def extract_svn_revno(rev):
             return svn_revno
 
 
-# TODO(jelmer): Rely on version from debmutate
 def upstream_version_add_revision(
         upstream_branch, version_string, revid, sep='+'):
     """Update the revision in a upstream version string.
@@ -236,52 +235,24 @@ def upstream_version_add_revision(
     try:
         revno = upstream_branch.revision_id_to_dotted_revno(revid)
     except GhostRevisionsHaveNoRevno:
-        pass
+        bzr_revno = None
     else:
-        revno_str = '.'.join(map(str, revno))
-
-        m = re.match(r"^(.*)([\+~])bzr(\d+)$", version_string)
-        if m:
-            return "%s%sbzr%s" % (m.group(1), m.group(2), revno_str)
+        bzr_revno = '.'.join(map(str, revno))
 
     rev = upstream_branch.repository.get_revision(revid)
     gitid = extract_gitid(rev)
     if gitid:
-        gitid = gitid[:7].decode('ascii')
-        gitdate = osutils.format_date(
-            rev.timestamp, rev.timezone, date_fmt='%Y%m%d', show_offset=False)
-
-    m = re.match(r"^(.*)([\+~-])git(\d{8})\.([a-f0-9]{7})$", version_string)
-    if m and gitid:
-        return "%s%sgit%s.%s" % (m.group(1), m.group(2), gitdate, gitid)
-
-    m = re.match(r"^(.*)([\+~-])git(\d{8})\.(\d+)\.([a-f0-9]{7})$",
-                 version_string)
-    if m and gitid:
-        if gitdate == m.group(3):
-            snapshot = int(m.group(4)) + 1
-        else:
-            snapshot = 0
-        return "%s%sgit%s.%d.%s" % (
-            m.group(1), m.group(2), gitdate, snapshot, gitid)
-
-    m = re.match(r"^(.*)([\+~-])git(\d{8})$", version_string)
-    if m and gitid:
-        return "%s%sgit%s" % (m.group(1), m.group(2), gitdate)
+        gitdate = date.fromisoformat(osutils.format_date(
+            rev.timestamp, rev.timezone, date_fmt='%Y-%m-%d',
+            show_offset=False))
+    else:
+        gitdate = None
 
     svn_revno = extract_svn_revno(rev)
 
-    m = re.match(r"^(.*)([\+~])svn(\d+)$", version_string)
-    # FIXME: Raise error if +svn/~svn is present and svn_revno is not set?
-    if m and svn_revno:
-        return "%s%ssvn%d" % (m.group(1), m.group(2), svn_revno)
-
-    if svn_revno:
-        return "%s%ssvn%d" % (version_string, sep, svn_revno)
-    elif gitid:
-        return "%s%sgit%s.1.%s" % (version_string, sep, gitdate, gitid)
-    else:
-        return "%s%sbzr%s" % (version_string, sep, revno_str)
+    return _upstream_version_add_revision(
+        version_string, gitid=gitid, gitdate=gitdate, bzr_revno=bzr_revno,
+        svn_revno=svn_revno)
 
 
 def get_snapshot_revision(upstream_version):
@@ -396,6 +367,8 @@ def guess_upstream_revspec(package, version):
     """Guess revspecs matching an upstream version string."""
     if version.endswith('+ds'):
         version = str(version)[:-len('+ds')]
+    if version.endswith('~ds'):
+        version = str(version)[:-len('~ds')]
     if version.endswith('+dfsg'):
         version = str(version)[:-len('+dfsg')]
     if version.endswith('+repack'):
@@ -580,8 +553,9 @@ class UpstreamBranchSource(UpstreamSource):
         if components is not None and components != [None]:
             # Multiple components are not supported
             raise PackageVersionNotPresent(package, version, self)
-        note("Looking for upstream %s in upstream branch %r.",
-             version, getattr(self, '_actual_branch', self.upstream_branch))
+        note("Looking for upstream %s in upstream branch %s.",
+             version,
+             getattr(self, '_actual_branch', self.upstream_branch).user_url)
         with self.upstream_branch.lock_read():
             if revisions is not None:
                 revid = revisions[None]
@@ -609,13 +583,15 @@ class UpstreamBranchSource(UpstreamSource):
             target_filename = self._tarball_path(
                 package, version, None, target_dir)
             try:
-                export(rev_tree, target_filename, 'tgz', tarball_base)
+                export_with_nested(
+                    rev_tree, target_filename, format='tgz', root=tarball_base)
             except UnsupportedOperation as e:
                 note('Not exporting revision from upstream branch: %s', e)
                 raise PackageVersionNotPresent(package, version, self)
             else:
-                note("Exporting upstream branch revision %s to create "
-                     "the tarball", revid)
+                mutter(
+                    "Exporting upstream branch revision %s to create "
+                    "the tarball", revid)
         return [target_filename]
 
     def __repr__(self):
@@ -694,6 +670,8 @@ def run_dist_command(
         except subprocess.CalledProcessError as e:
             if e.returncode == 2:
                 raise NotImplementedError
+            if e.returncode == 137:
+                raise MemoryError(str(e))
             try:
                 import json
                 with open(env['DIST_RESULT'], 'r') as f:
@@ -718,7 +696,7 @@ def run_dist_command(
         if include_controldir:
             _dupe_vcs_tree(rev_tree, package_dir)
         else:
-            export(rev_tree, package_dir, 'dir')
+            export_with_nested(rev_tree, package_dir, format='dir')
         existing_files = os.listdir(package_dir)
         try:
             _run_and_interpret(dist_command, env, package_dir)
